@@ -634,6 +634,8 @@ impl NcPlane {
 
     /// Sets this NcPlane's base [NcCell] from its components.
     ///
+    /// Returns the number of bytes copied out of `egc` if succesful.
+    ///
     /// It will be used for purposes of rendering anywhere that the NcPlane's
     /// gcluster is 0.
     ///
@@ -977,7 +979,7 @@ impl NcPlane {
         let (y, x) = self.yx();
         error![
             unsafe { crate::ncplane_move_yx(self, y + rows, x + cols) },
-            &format!("NcPlane.move_yx({}, {})", y, x)
+            &format!("NcPlane.move_rel({}, {})", rows, cols)
         ]
     }
 
